<?php

namespace Drupal\firebase_ui\Controller;

use Symfony\Component\HttpFoundation\Response;

/**
 * Returns the dynamic service worker JavaScript for authenticated users.
 */
class ServiceWorkerController {

  /**
   * Outputs the dynamic Firebase Service Worker JavaScript.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   A JavaScript response with Firebase configuration.
   */
  public function sw() {
    $current_user = \Drupal::currentUser();

    // Only allow logged-in users.
    if ($current_user->isAnonymous()) {
      return new Response('// Service Worker: Access denied', 403, [
        'Content-Type' => 'application/javascript',
      ]);
    }

    // Load Firebase config from Drupal settings.
    $config = \Drupal::config('firebase_ui.settings');

    $firebase_config = json_encode([
      'appId' => $config->get('appId'),
      'apiKey' => $config->get('apiKey'),
      'projectId' => $config->get('projectId'),
      'messagingSenderId' => $config->get('messagingSenderId'),
      'authDomain' => $config->get('authDomain') . ".firebaseapp.com",
    ], JSON_UNESCAPED_SLASHES);

    $js = <<<JS
importScripts('https://www.gstatic.com/firebasejs/10.7.0/firebase-app-compat.js');
importScripts('https://www.gstatic.com/firebasejs/10.7.0/firebase-messaging-compat.js');

firebase.initializeApp($firebase_config);

const messaging = firebase.messaging();
messaging.onBackgroundMessage(function(payload) {
  self.registration.showNotification(payload.notification.title, {
    body: payload.notification.body,
    icon: '/logo.png'
  });
});
JS;

    return new Response($js, 200, ['Content-Type' => 'application/javascript']);
  }

}
